@@ -15,6 +15,12 @@ __PACKAGE__->has_a(
   inflate => sub { Date::Simple->new(shift) },
   deflate => 'format',
 );
+
+# Disables the implicit autoinc-on-non-supplied-pk behavior
+# (and the warning that goes with it)
+# This is the same behavior as it was pre 0.082900
+__PACKAGE__->column_info('myid')->{is_auto_increment} = 0;
+
 #__PACKAGE__->find_column('tdate')->placeholder("IF(1, CURDATE(), ?)");
 
 sub create_sql {
